Plugins/VcsPlugins/vcsSubversion/ProjectHelper.py

branch
5_4_x
changeset 3474
ca4b926f1bbb
parent 3160
209a07d7e401
diff -r 741ab2eecaf9 -r ca4b926f1bbb Plugins/VcsPlugins/vcsSubversion/ProjectHelper.py
--- a/Plugins/VcsPlugins/vcsSubversion/ProjectHelper.py	Wed Apr 02 19:08:31 2014 +0200
+++ b/Plugins/VcsPlugins/vcsSubversion/ProjectHelper.py	Thu Apr 03 19:12:51 2014 +0200
@@ -126,7 +126,7 @@
         self.actions.append(self.svnLogBrowserAct)
         
         self.vcsDiffAct = E5Action(
-            self.trUtf8('Show difference'),
+            self.trUtf8('Show differences'),
             UI.PixmapCache.getIcon("vcsDiff.png"),
             self.trUtf8('Show &difference'),
             0, 0, self, 'subversion_diff')
@@ -134,40 +134,40 @@
             'Show the difference of the local project to the repository'
         ))
         self.vcsDiffAct.setWhatsThis(self.trUtf8(
             """<b>Show difference</b>"""
             """<p>This shows the difference of the local project to the"""
             """ repository.</p>"""
         ))
         self.vcsDiffAct.triggered[()].connect(self._vcsDiff)
         self.actions.append(self.vcsDiffAct)
         
         self.svnExtDiffAct = E5Action(
-            self.trUtf8('Show difference (extended)'),
+            self.trUtf8('Show differences (extended)'),
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show difference (extended)'),
+            self.trUtf8('Show differences (extended)'),
             0, 0, self, 'subversion_extendeddiff')
         self.svnExtDiffAct.setStatusTip(self.trUtf8(
             'Show the difference of revisions of the project to the repository'
         ))
         self.svnExtDiffAct.setWhatsThis(self.trUtf8(
             """<b>Show difference (extended)</b>"""
             """<p>This shows the difference of selectable revisions of"""
             """ the project.</p>"""
         ))
         self.svnExtDiffAct.triggered[()].connect(self.__svnExtendedDiff)
         self.actions.append(self.svnExtDiffAct)
         
         self.svnUrlDiffAct = E5Action(
-            self.trUtf8('Show difference (URLs)'),
+            self.trUtf8('Show differences (URLs)'),
             UI.PixmapCache.getIcon("vcsDiff.png"),
-            self.trUtf8('Show difference (URLs)'),
+            self.trUtf8('Show differences (URLs)'),
             0, 0, self, 'subversion_urldiff')
         self.svnUrlDiffAct.setStatusTip(self.trUtf8(
             'Show the difference of the project between two repository URLs'
         ))
         self.svnUrlDiffAct.setWhatsThis(self.trUtf8(
             """<b>Show difference (URLs)</b>"""
             """<p>This shows the difference of the project between"""
             """ two repository URLs.</p>"""
         ))
         self.svnUrlDiffAct.triggered[()].connect(self.__svnUrlDiff)
@@ -134,40 +134,40 @@
         ))
         self.vcsDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference</b>"""
-            """<p>This shows the difference of the local project to the"""
+            """<b>Show differences</b>"""
+            """<p>This shows differences of the local project to the"""
             """ repository.</p>"""
         ))
@@ -134,40 +134,40 @@
         ))
         self.svnExtDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference (extended)</b>"""
-            """<p>This shows the difference of selectable revisions of"""
+            """<b>Show differences (extended)</b>"""
+            """<p>This shows differences of selectable revisions of"""
             """ the project.</p>"""
         ))
@@ -134,40 +134,40 @@
         ))
         self.svnUrlDiffAct.setWhatsThis(self.trUtf8(
-            """<b>Show difference (URLs)</b>"""
-            """<p>This shows the difference of the project between"""
+            """<b>Show differences (URLs)</b>"""
+            """<p>This shows differences of the project between"""
             """ two repository URLs.</p>"""
         ))

eric ide

mercurial